from unittest import TestCase
from rusenttokenize import ru_sent_tokenize


class TestRuSentTokenize(TestCase):
    def test_ru_sent_tokenize(self):
        self.assertEqual(ru_sent_tokenize('купил за 5 руб. и остался доволен.'),
                         ['купил за 5 руб. и остался доволен.'])
        self.assertEqual(ru_sent_tokenize('Я ему сказал и т.к. он не послушался за 500р.'),
                         ['Я ему сказал и т.к. он не послушался за 500р.'])
        self.assertEqual(ru_sent_tokenize('Ура. Ура. 500р.'), ['Ура.', 'Ура.', '500р.'])
        self.assertEqual(ru_sent_tokenize(
            'Среди других её представителей — Л. Р. Зиндер, Л. В. Бондарко, М. И. Матусевич.'),
            ['Среди других её представителей — Л. Р. Зиндер, Л. В. Бондарко, М. И. Матусевич.'])
        self.assertEqual(ru_sent_tokenize('И. П. Павлов.'), ['И. П. Павлов.'])
        self.assertEqual(ru_sent_tokenize('Павлов И. П., Сеченов И. М.'), ['Павлов И. П., Сеченов И. М.'])
        self.assertEqual(ru_sent_tokenize('Основателем школы является Л. В. Щерба.'),
                         ['Основателем школы является Л. В. Щерба.'])
        self.assertEqual(ru_sent_tokenize('Я ему сказале: "Чтобы ничего не трогале." Но он не послушался.'),
                         ['Я ему сказале: "Чтобы ничего не трогале."', 'Но он не послушался.'])
        self.assertEqual(ru_sent_tokenize('Нефть за $27/барр. не снится.'), ['Нефть за $27/барр. не снится.'])
        self.assertEqual(ru_sent_tokenize('Сказала я. Он оглянулся.'), ['Сказала я.', 'Он оглянулся.'])
        self.assertEqual(ru_sent_tokenize(
            'Летописец Нестор относит их возникновение к I столетию н.э., когда св. Андрей, проповедуя в Киеве '
            'евангельское слово, отправился потом в Новгород, где он увидел чудо – парившихся в бане.'),
            ['Летописец Нестор относит их возникновение к I столетию н.э., когда св. Андрей, проповедуя в Киеве '
             'евангельское слово, отправился потом в Новгород, где он увидел чудо – парившихся в бане.'])
        self.assertEqual(ru_sent_tokenize(
            '- Ну, хорошо, хочешь, я тебе тоннели покажу? - спрашивает наконец Мариам и сворачивает с одной ничем '
            'не примечательной улицы, застроенной обычными городскими многоэтажками, на другую точно такую же.'),
            ['- Ну, хорошо, хочешь, я тебе тоннели покажу? - спрашивает наконец Мариам и сворачивает с одной ничем '
             'не примечательной улицы, застроенной обычными городскими многоэтажками, на другую точно такую же.'])
        self.assertEqual(ru_sent_tokenize('Где они были эти …адцать лет?'), ['Где они были эти …адцать лет?'])
        self.assertEqual(ru_sent_tokenize('Православие... более всего подходит на роль такой идеи...'),
                         ['Православие... более всего подходит на роль такой идеи...'])
        self.assertEqual(ru_sent_tokenize('Yolka стоит 2400р. без трех копеек сто долларов, между прочим.'),
                         ['Yolka стоит 2400р. без трех копеек сто долларов, между прочим.'])
        self.assertEqual(ru_sent_tokenize(
            'А если лень читать всё - общее количество ответов: 8272! - то можно почитать книжку избранных мест.'),
            ['А если лень читать всё - общее количество ответов: 8272! - то можно почитать книжку избранных мест.'])
        self.assertEqual(ru_sent_tokenize('Это стоило 50 т. к. вчера'), ['Это стоило 50 т. к. вчера'])
        self.assertEqual(ru_sent_tokenize("Официально закрытие фастфудов назначено на предстоящее воскресенье, "
                                           "причём менеджеры не планируют снова открывать в этой стране рестораны "
                                           "McDonald's. Причин закрытия исландских McDonald's несколько."),
                         ["Официально закрытие фастфудов назначено на предстоящее воскресенье, причём "
                          "менеджеры не планируют снова открывать в этой стране рестораны McDonald's.",
                          "Причин закрытия исландских McDonald's несколько."])
        self.assertEqual(ru_sent_tokenize('12 января ожидается понижение до минус 44 — минус 48°C. '
                                           'В школах региона отменены занятия в начальных классах.'),
                         ['12 января ожидается понижение до минус 44 — минус 48°C.',
                          'В школах региона отменены занятия в начальных классах.'])
        self.assertEqual(ru_sent_tokenize(
            'У государственных людей тоже есть дети, и если для них ночные заведения работать-таки будут… (а вы '
            'попробуйте им отказать) ну, в общем, не хотелось бы думать о волне народного возмущения.'),
               ['У государственных людей тоже есть дети, и если для них ночные заведения работать-таки будут… (а вы '
                'попробуйте им отказать) ну, в общем, не хотелось бы думать о волне народного возмущения.'])
        self.assertEqual(ru_sent_tokenize('По сравнению с 2009 годом Россия опустилась в рейтинге на 9 позиций '
                                          '(т. е. ситуация в ней улучшилась).'),
                         ['По сравнению с 2009 годом Россия опустилась в рейтинге на 9 позиций (т. е. ситуация'
                          ' в ней улучшилась).'])
        self.assertEqual(ru_sent_tokenize(
            'Привет.Тест (прим. ред. - на токенизацию). \"По моим наблюдениям, выгоднее было бы поставлять газ в '
            'Азию через Аравийское море. Проект иранской газовой трубы через Турцию — долгосрочная перспектива\", -'
            ' сказал Сайед Мухаммед Хусейн Адели.'),
            ['Привет.Тест (прим. ред. - на токенизацию).',
             '"По моим наблюдениям, выгоднее было бы поставлять газ в Азию через Аравийское море.',
             'Проект иранской газовой трубы через Турцию — долгосрочная перспектива", - сказал Сайед Мухаммед Хусейн '
             'Адели.'])
